/**
 * @file
 * Javascript for gliderjs configuracion.
 *
 * Available variables:
 * - slides_to_show: The number of slides to show in container.
 * - slides_to_scroll: The number of slides to scroll with arrow navigation.
 * - show_arrows: Show Arrows.
 * - show_dots: Show Dots.
 * - item_width: The item width.
 * - exact_width: The exact width.
 * - scroll_lock: If scroll to the nearest slide after any scroll interactions.
 * - scroll_lock_delay: Delay in milliseconds to wait before the scroll happens.
 * - resize_lock: If the nearest slide on resizing of the window will be locked.
 * - rewind: Scroll to beginning/end when its respective endpoint is reached.
 * - draggable: The list can be scrolled by click and dragging with the mouse.
 * - drag_velocity: How much to aggravate the velocity of the mouse dragging.
 * - duration: An aggravator used to control animation speed. Higher is slower!
 * - breakpoint_settings: Breakpoint Settings.
 *
 **/
window.addEventListener('load', function () {
  window.glides = new Glider(document.getElementById('glider'), {
    slidesToShow: drupalSettings.gliderjs.slides_to_show,
    slidesToScroll: drupalSettings.gliderjs.slides_to_scroll,
    dots: '.dots',
    arrows: {
      prev: '.glider-prev',
      next: '.glider-next'
    },
    itemWidth: drupalSettings.gliderjs.item_width,
    exactWidth: drupalSettings.gliderjs.exact_width,
    scrollLock: drupalSettings.gliderjs.scroll_lock,
    scrollLockDelay: drupalSettings.gliderjs.scroll_lock_delay,
    resizeLock: drupalSettings.gliderjs.resize_lock,
    rewind: drupalSettings.gliderjs.rewind,
    draggable: drupalSettings.gliderjs.draggable,
    dragVelocity: drupalSettings.gliderjs.drag_velocity,
    duration: drupalSettings.gliderjs.duration,
  })
})
